setuplib
========

The ‘setuptetx‘ package provides an easy to use regression test interface for all supported platforms.

The current supported implementations are:

* CPython

* IPython

* IronPython

* Jython

* PyPy

The current supported platforms are:

* Linux, BSD, Unix, OS-X, Cygwin, and Windows

* x86, amd64, arm32/armhf, arm64/aarch64

* Servers, Workstations, Embedded Systems

* Datacenters, public and private Clouds, IoT 

For more extensions refer to the online documentation.

**Online documentation**:

* https://setuptestx.sourceforge.io/

**Runtime-Repository**:

* PyPI: https://pypi.org/project/setuptestx/

  Install: *pip install setuplib*, see also section 'Install' of the online documentation.


**Downloads**:

* sourceforge.net: https://sourceforge.net/projects/setuptestx/files/

* bitbucket.org: https://bitbucket.org/acue/setuptestx

* github.com: https://github.com/ArnoCan/setuptestx/

* pypi.org: https://pypi.org/project/setuptestx/


Project Data
------------

* PROJECT: 'setuptestx'

* MISSION: Command extension of *setup.py* for multi-platform regression tests.

* VERSION: 00.01

* RELEASE: 00.01.042

* STATUS: alpha

* AUTHOR: Arno-Can Uestuensoez

* COPYRIGHT: Copyright (C) 2019 Arno-Can Uestuensoez @Ingenieurbuero Arno-Can Uestuensoez

* LICENSE: Artistic-License-2.0 + Forced-Fairplay-Constraints

Concepts and enumeration values are migrated from the 

* *UnifiedSessionsManager* (C) 2008 Arno-Can Uestuensoez @Ingenieurbuero Arno-Can Uestuensoez.  

Runtime Environment
-------------------
For a comprehensive list refer to the documentation.

**Python Syntax Support**

*  Python2.7, and Python3

**Python Implementation Support**

*  CPython, IPython, IronPython, Jython, and PyPy

**OS on Server, Workstation, Laptops, Virtual Machines, and Containers**

* Linux: AlpineLinux, ArchLinux, CentOS, Debian, Fedora, Gentoo, OpenSUSE, Raspbian, RHEL, Slackware, SLES, Ubuntu, ...  

* BSD: DragonFlyBSD, FreeBSD, NetBSD, OpenBSD, GhostBSD, TrueOS, NomadBSD

* OS-X: Snow Leopard

* Windows: Win10, Win8.1, Win7, WinXP, Win2019, Win2016, Win2012, Win2008, Win2000

* WSL-1.0: Alpine, Debian, KaliLinux, openSUSE, SLES, Ubuntu

* Cygwin

* UNIX: Solaris10, Solaris11

* Minix: Minix3

* ReactOS

**Network and Security**

* Network Devices: OpenWRT

* Security: KaliLinux, pfSense

**OS on Embedded Devices**

* RaspberryPI: ArchLinux, CentOS, OpenBSD, OpenWRT, Raspbian

* ASUS-TinkerBoard: Armbian

**Creation of Special Deployment Packages**

* MicroPython: CircuitPython, MicroPython

Current Release
---------------

REMARK:
   Currently tested by application to the other projects of the author.
   So for now no package tests defined.

Major Changes:

* Initial version.

ToDo:

* Deployment to remote MicroPython, and CircuitPython

